(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['api/Payment', 'model/ConfirmPaymentTokenRequest', 'model/PaymentToken', 'model/Fee'], factory);
    } else if (typeof module === 'object' && module.exports) {
        // CommonJS-like environments that support module.exports, like Node.
        module.exports = factory(require('./Payment'), require('../model/ConfirmPaymentTokenRequest'), require('../model/PaymentToken'), require('../model/Fee'));
    } else {
        // Browser globals (root is window)
        if (!root.OrbipayCheckoutApIs) {
            root.OrbipayCheckoutApIs = {};
        }
        root.OrbipayCheckoutApIs.PaymentTokenApi = factory(root.OrbipayCheckoutApIs.Payment, root.OrbipayCheckoutApIs.ConfirmPaymentTokenRequest, root.OrbipayCheckoutApIs.PaymentToken, root.OrbipayCheckoutApIs.Fee);
    }
}(this, function (Payment, ConfirmPaymentTokenRequest, PaymentToken, Fee) {
    'use strict';

    var exports = function (customerAccountReference, amount) {

        this.payment = new Payment();
        this.token = null;
        this.digiSign = null;
        this.customFields = null;
        this.paymentToken = new PaymentToken();
        this.fee = new Fee();

        this.forClient = function(clientId, signatureKey){
            this.payment.apiClient.clientId = clientId;
            this.payment.apiClient.signatureKey = signatureKey;
            return this;
        }

        this.forPartner = function(clientId, signatureKey){
            this.payment.apiClient.clientId = clientId;
            this.payment.apiClient.signatureKey = signatureKey;
            return this;
        }

        this.withToken = function(token, digiSign){
            if(typeof token === 'string' || token instanceof String){
                this.paymentToken.token = token;
                this.paymentToken.tokenized_amount = amount;            
            } else{
                this.paymentToken = token;
            }
            this.digiSign = digiSign;
            return this;
        }

        this.withCustomFields = function(customFields){
          this.customFields = customFields;
            return this;
        }

        this.withFee = function(feeAmount){
          this.fee.fee_amount = feeAmount;
            return this;
        }

        this.confirm = function(callback){
            var confirmPaymentTokenRequest = new ConfirmPaymentTokenRequest();
            confirmPaymentTokenRequest.customer_account_reference = customerAccountReference;
            confirmPaymentTokenRequest.custom_fields = this.customFields;
            confirmPaymentTokenRequest.payment_token = this.paymentToken;
            confirmPaymentTokenRequest.fee_amount = this.fee.fee_amount;
            this.payment.confirmPaymentToken(this.payment.apiClient.clientId, confirmPaymentTokenRequest, this.digiSign, callback);
        }

    };

    return exports;
}));
